import { alertService } from '@/helpers/AlertService';
import {
  Form, LoadingService,
} from '@zeedhi/common';
import { Http, Metadata } from '@zeedhi/core';

type StorageData = {
  [key: string]: string | boolean | number;
};

type StorageMode = 'localstorage' | 'cookie';

export class LoginController {
  public getInstanceFromLoginForm() {
    const form = Metadata.getInstance<Form>('login-form');
    const email = form.value['login-email-input'];
    const password = form.value['login-password-input'];

    return {
      email,
      password,
    };
  }

  public async login() {
    try {
      const form = this.getInstanceFromLoginForm();
      LoadingService.show();

      const { data } = await Http.post('/operator/login', form);

      if (data.error) throw new Error(data.message);

      const {
        token: TOKEN, operator: {
          ID, NAME, EMAIL, NRORG,
        },
      } = data.data;

      this.storeData({
        ID, NAME, EMAIL, TOKEN,
      }, 'localstorage');

      this.storeData({ NRORG }, 'cookie');

      const { data: accessProfile } = await Http.post('/operator/accessProfile', {});

      this.storeData({
        PERMISSIONS: btoa(JSON.stringify(accessProfile.data)),
      }, 'localstorage');

      window.location.href = '/dashboard';
    } catch (error) {
      if (error instanceof Error) {
        alertService('error', error.message, 'red');
      }
    } finally {
      LoadingService.hide();
    }
  }

  private storeData(storageData: StorageData = {}, type: StorageMode = 'localstorage') {
    Object.keys(storageData).forEach((key: string) => {
      const value = storageData[key];
      if (type === 'localstorage') {
        localStorage.setItem(key, (value || '').toString());
      } else if (type === 'cookie') {
        document.cookie = `${key}=${value}; path=/`;
      }
    });
  }

  public logout(): void {
    window.location.href = '/login';
    localStorage.clear();
  }
}
