import {
  alertService,
} from '@/helpers/AlertService';
import {
  Http,
} from '@zeedhi/core';
import { LoadingService } from '@zeedhi/common';

class ReportsController {
  public async exportsReportsPDF(title: string, paramsFilter: any, visibleColumns: string[]) {
    try {
      const params = {
        title,
        paramsFilter,
        visibleColumns,
      };

      LoadingService.show();
      const { data, error, message } = await Http.post('/reports/exportPDF', params, { responseType: 'arraybuffer' });

      if (error) throw new Error(message);

      const blob = new Blob([data], { type: 'application/pdf' });
      const link = document.createElement('a');
      link.href = window.URL.createObjectURL(blob);
      link.download = `${title}.pdf`;
      link.click();
      window.URL.revokeObjectURL(link.href);
    } catch (error) {
      if (error instanceof Error) {
        alertService('error', error.message, 'red');
      }
    } finally {
      LoadingService.hide();
    }
  }

  public async exportsReportsXLS(title: string, paramsFilter: any, visibleColumns: string[]) {
    try {
      const params = {
        title,
        paramsFilter,
        visibleColumns,
      };

      LoadingService.show();
      const { data, error, message } = await Http.post('/reports/exportXLS', params);

      if (error) throw new Error(message);

      const base64Content = data.data;
      const binaryContent = atob(base64Content);
      const byteArray = new Uint8Array(binaryContent.length);

      binaryContent.split('').forEach((char, i) => {
        byteArray[i] = char.charCodeAt(0);
      });

      const blob = new Blob([byteArray], { type: 'application/vnd.ms-excel' });
      const link = document.createElement('a');

      link.href = window.URL.createObjectURL(blob);
      link.download = `${title}.xls`;
      link.click();
      window.URL.revokeObjectURL(link.href);
    } catch (error) {
      if (error instanceof Error) {
        alertService('error', error.message, 'red');
      }
    } finally {
      LoadingService.hide();
    }
  }
}

export default new ReportsController();
